unit EanRBDB;

interface
uses EanKod,DB,DbTables,DbCtrls,Classes,Controls,Messages, EanRB,
     ppCtrls, ppDsgnCt, ppDevice, ppDrwCmd, ppTypes, ppClass;

type
  TRBDBEan = class(TRBEan)
     private
            FDataLink: TFieldDataLink;
            function GetDataField: string;
            function GetDataSource: TDataSource;
            function GetField: TField;
            function GetFieldText: string;
            procedure SetDataField(const Value: string);
            procedure SetDataSource(Value: TDataSource);
            procedure CMGetDataLink(var Message: TMessage); message CM_GETDATALINK;
     protected
            procedure Loaded; override;
            procedure Notification(AComponent: TComponent; Operation: TOperation); override;
            procedure DataChange(Sender: TObject);
     public
            constructor Create(AOwner: TComponent); override;
            destructor Destroy; override;
            property Field: TField read GetField;
     published
            property DataField: string read GetDataField write SetDataField;
            property DataSource: TDataSource read GetDataSource write SetDataSource;
  end;


  TRbDbEanMemo = class(TRBEanMemo)
     private
            FDataLink: TFieldDataLink;
            function GetDataField: string;
            function GetDataSource: TDataSource;
            function GetField: TField;
            procedure SetDataField(const Value: string);
            procedure SetDataSource(Value: TDataSource);
            procedure CMGetDataLink(var Message: TMessage); message CM_GETDATALINK;
     protected
            procedure Loaded; override;
            procedure Notification(AComponent: TComponent; Operation: TOperation); override;
            procedure DataChange(Sender: TObject);
     public
            constructor Create(AOwner: TComponent); override;
            destructor Destroy; override;
            property Field: TField read GetField;
     published
            property DataField: string read GetDataField write SetDataField;
            property DataSource: TDataSource read GetDataSource write SetDataSource;
  end;


implementation

constructor TRbDBEan.Create(AOwner: TComponent);
begin
  inherited Create(AOwner);
  // ControlStyle := ControlStyle + [csReplicatable];
  FDataLink := TFieldDataLink.Create;
  FDataLink.Control := Self;
  FDataLink.OnDataChange := DataChange;
end;

destructor TRbDBEan.Destroy;
begin
  FDataLink.Free;
  FDataLink := nil;
  inherited Destroy;
end;

procedure TRbDBEan.Loaded;
begin
  inherited Loaded;
  if (csDesigning in ComponentState) then DataChange(Self);
end;

procedure TRbDBEan.Notification(AComponent: TComponent;
  Operation: TOperation);
begin
  inherited Notification(AComponent, Operation);
  if (Operation = opRemove) and (FDataLink <> nil) and
    (AComponent = DataSource) then DataSource := nil;
end;

function TRbDBEan.GetDataSource: TDataSource;
begin
  Result := FDataLink.DataSource;
end;

procedure TRbDBEan.SetDataSource(Value: TDataSource);
begin
  FDataLink.DataSource := Value;
  if Value <> nil then Value.FreeNotification(Self);
end;

function TRbDBEan.GetDataField: string;
begin
  Result := FDataLink.FieldName;
end;

procedure TRbDBEan.SetDataField(const Value: string);
begin
  FDataLink.FieldName := Value;
end;

function TRbDBEan.GetField: TField;
begin
  Result := FDataLink.Field;
end;

function TRbDBEan.GetFieldText: string;
begin
  if FDataLink.Field <> nil then
    Result := FDataLink.Field.DisplayText
  else
    if csDesigning in ComponentState then Result := Name else Result := '';
end;

procedure TRbDBEan.DataChange(Sender: TObject);
begin
  BarCode:= GetFieldText;
end;

procedure TRbDBEan.CMGetDataLink(var Message: TMessage);
begin
  Message.Result := Integer(FDataLink);
end;



constructor TRbDBEanMemo.Create(AOwner: TComponent);
begin
  inherited Create(AOwner);
  // ControlStyle := ControlStyle + [csReplicatable];
  FDataLink := TFieldDataLink.Create;
  FDataLink.Control := Self;
  FDataLink.OnDataChange := DataChange;
end;

destructor TRbDBEanMemo.Destroy;
begin
  FDataLink.Free;
  FDataLink := nil;
  inherited Destroy;
end;

procedure TRbDBEanMemo.Loaded;
begin
  inherited Loaded;
  if (csDesigning in ComponentState) then DataChange(Self);
end;

procedure TRbDBEanMemo.Notification(AComponent: TComponent;
  Operation: TOperation);
begin
  inherited Notification(AComponent, Operation);
  if (Operation = opRemove) and (FDataLink <> nil) and
    (AComponent = DataSource) then DataSource := nil;
end;

function TRbDBEanMemo.GetDataSource: TDataSource;
begin
  Result := FDataLink.DataSource;
end;

procedure TRbDBEanMemo.SetDataSource(Value: TDataSource);
begin
  FDataLink.DataSource := Value;
  if Value <> nil then Value.FreeNotification(Self);
end;

function TRbDBEanmemo.GetDataField: string;
begin
  Result := FDataLink.FieldName;
end;

procedure TRbDBEanMemo.SetDataField(const Value: string);
begin
  FDataLink.FieldName := Value;
end;

function TRbDBEanMemo.GetField: TField;
begin
  Result := FDataLink.Field;
end;

procedure TRbDBEanMemo.DataChange(Sender: TObject);
begin
     if FDataLink.Field<>nil then
        if FDataLink.Field.IsBlob then begin
           try
              Lines.Text := FDataLink.Field.AsString;
           except
              Lines.Text := '';
           end;
           Invalidate;
        end;
end;

procedure TRbDBEanMemo.CMGetDataLink(var Message: TMessage);
begin
  Message.Result := Integer(FDataLink);
end;


initialization
  ppRegisterComponent(TRBDBEan, 'Ean components', 10, 0, 'RbDBEan', HInstance);
  ppRegisterComponent(TRBDBEanMemo, 'Ean components', 10, 0, 'RbRBEanMemo', HInstance);

finalization

  ppUnRegisterComponent(TRbDbEan);
  ppUnRegisterComponent(TRbDbEanMemo);

end.
